.. _designtoc:

Design Phases
=============

The following pages cover the methodology behind the design phases available in
the model.

.. toctree::
   :maxdepth: 1

   phases/design/doc_MonopileDesign
   phases/design/doc_ScourProtectionDesign
   phases/design/doc_ArraySystemDesign
   phases/design/doc_ExportSystemDesign
   phases/design/doc_ElectricalDesign
   phases/design/doc_OffshoreSubstationDesign
   phases/design/doc_SemiSubmersibleDesign
   phases/design/doc_SparDesign
   phases/design/doc_MooringSystemDesign
